@@ -23,6 +23,9 @@
 #include "gailoptionmenu.h"
 
 static void                  gail_option_menu_class_init       (GailOptionMenuClass *klass);
+static void		     gail_option_menu_real_initialize  (AtkObject       *obj,
+                                                                gpointer        data);
+
 static gint                  gail_option_menu_get_n_children   (AtkObject       *obj);
 static AtkObject*            gail_option_menu_ref_child        (AtkObject       *obj,
                                                                 gint            i);
@@ -97,6 +100,7 @@ gail_option_menu_class_init (GailOptionMenuClass *klass)
 
   class->get_n_children = gail_option_menu_get_n_children;
   class->ref_child = gail_option_menu_ref_child;
+  class->initialize = gail_option_menu_real_initialize;
 
   container_class->add_gtk = gail_option_menu_real_add_gtk;
   container_class->remove_gtk = gail_option_menu_real_remove_gtk;
@@ -116,11 +120,18 @@ gail_option_menu_new (GtkWidget *widget)
   accessible = ATK_OBJECT (object);
   atk_object_initialize (accessible, widget);
 
-  accessible->role = ATK_ROLE_COMBO_BOX;
-
   return accessible;
 }
 
+static void
+gail_option_menu_real_initialize (AtkObject *obj,
+                                  gpointer  data)
+{
+  ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
+
+  obj->role = ATK_ROLE_COMBO_BOX;
+}
+
 static gint
 gail_option_menu_get_n_children (AtkObject *obj)
 {
@@ -139,11 +150,8 @@ gail_option_menu_get_n_children (AtkObject *obj)
 
   option_menu = GTK_OPTION_MENU (widget);
   if (gtk_option_menu_get_menu (option_menu))
-    {
       n_children++;
-      if (option_menu->menu_item)
-        n_children++;
-    }
+
   return n_children;;
 }
 
@@ -166,18 +174,7 @@ gail_option_menu_ref_child (AtkObject *obj,
 
 
   if (i == 0)
-    accessible = g_object_ref( gtk_widget_get_accessible (gtk_option_menu_get_menu (GTK_OPTION_MENU (widget))));
-  else if (i == 1)
-    {
-      children = gtk_container_get_children (GTK_CONTAINER (widget));
-
-      if (!children)
-        return NULL;
-
-      accessible = gtk_widget_get_accessible (GTK_WIDGET (children->data));
-      g_object_ref (accessible);
-      g_list_free (children);
-    }
+    accessible = g_object_ref (gtk_widget_get_accessible (gtk_option_menu_get_menu (GTK_OPTION_MENU (widget))));
    else
     accessible = NULL;
 
