@@ -211,6 +211,13 @@ gail_window_new (GtkWidget *widget)
   accessible = ATK_OBJECT (object);
   atk_object_initialize (accessible, widget);
 
+  /*
+   * Notify that tooltip is showing
+   */
+  if (accessible->role == ATK_ROLE_TOOL_TIP &&
+      GTK_WIDGET_MAPPED (widget))
+    atk_object_notify_state_change (accessible, ATK_STATE_SHOWING, 1);
+
   return accessible;
 }
 
